// this file is meant to be #included

#include <lib/config.mi>

// -----------------------------------------------------------------------------------------------------------------

// this is the page that maps its items to the options menu, you can add attribs or more pages (submenus)
#define CUSTOM_OPTIONSMENU_ITEMS "{1828D28F-78DD-4647-8532-EBA504B8FC04}"

// this is the page that maps its items to the windows menu (aka View), you can add attribs or more pages (submenus)
#define CUSTOM_WINDOWSMENU_ITEMS "{6559CA61-7EB2-4415-A8A9-A2AEEF762B7F}"

// custom options submenu item page, you can add more, just use guidgen and Config.newItem()
#define CUSTOM_PAGE "{26E26319-AECA-4433-B8F1-F4A5BF2A9ED5}"

// this is used to temporarilly disable playback stop on video window close, in case it's set
#define SKINTWEAKS_CFGPAGE "{0542AFA4-48D9-4c9f-8900-5739D52C114F}"

// drawer config page
#define CUSTOM_PAGE_DRAWER "{C338B30F-2A04-4b10-871F-4E9D52D62806}"

// menubars config page
#define CUSTOM_PAGE_MENUBARS "{12ED320E-6813-45ac-9F8E-78EE5B2B5F6D}"

// main windowshade config page
#define CUSTOM_PAGE_WINDOWSHADE "{58F07E21-AE96-4899-B7BC-3640B40029FB}"

// -----------------------------------------------------------------------------------------------------------------

Function initAttribs();

// -----------------------------------------------------------------------------------------------------------------

Global ConfigAttribute scrolldrawerattrib;

Global ConfigAttribute vis_detach_attrib;
Global ConfigAttribute video_detach_attrib;

Global ConfigAttribute drawer_directiontop_attrib;
Global ConfigAttribute drawer_directionbottom_attrib;
Global ConfigAttribute drawer_directionbypass_attrib;

Global ConfigAttribute eq_visible_attrib;

Global ConfigAttribute menubar_main_attrib;
Global ConfigAttribute menubar_pe_attrib;
Global ConfigAttribute menubar_ml_attrib;

Global ConfigAttribute windowshade_linkall_attrib;
Global ConfigAttribute windowshade_linkposition_attrib;
Global ConfigAttribute windowshade_linknone_attrib;

// -----------------------------------------------------------------------------------------------------------------

initAttribs() {

	// create the custom cfgpage for this session (if it does exist, it just returns it)
	ConfigItem custom_page = Config.newItem("Winamp Modern", CUSTOM_PAGE);
	ConfigItem custom_page_drawer = Config.newItem("Drawer", CUSTOM_PAGE_DRAWER);
	ConfigItem custom_page_menubars = Config.newItem("Menus", CUSTOM_PAGE_MENUBARS);
	ConfigItem custom_page_windowshade = Config.newItem("Main Windowshade Mode", CUSTOM_PAGE_WINDOWSHADE);

	// load up the cfgpage in which we'll insert our custom page
	ConfigItem custom_options_page = Config.getItem(CUSTOM_OPTIONSMENU_ITEMS);
	ConfigItem custom_windows_page = Config.getItem(CUSTOM_WINDOWSMENU_ITEMS);

	// this creates a submenu for this attribute
	ConfigAttribute submenuattrib = custom_options_page.newAttribute("Winamp Modern", "");
	submenuattrib.setData(CUSTOM_PAGE); // discard any default value and point at our custom cfgpage

	ConfigAttribute drawersubmenu = custom_page.newAttribute("Drawer", "");
	drawersubmenu.setData(CUSTOM_PAGE_DRAWER);

	ConfigAttribute menubarssubmenu = custom_page.newAttribute("Menus", "");
	menubarssubmenu.setData(CUSTOM_PAGE_MENUBARS);

	ConfigAttribute windowshadesubmenu = custom_page.newAttribute("Main Windowshade Mode", "");
	windowshadesubmenu.setData(CUSTOM_PAGE_WINDOWSHADE);

	scrolldrawerattrib = custom_page_drawer.newAttribute("Animate", "0");
	ConfigAttribute sep = custom_page_drawer.newAttribute("sep1", ""); sep.setData("-");
	drawer_directiontop_attrib = custom_page_drawer.newAttribute("Open from the top", "0");
	drawer_directionbottom_attrib = custom_page_drawer.newAttribute("Open from the bottom", "1");
	drawer_directionbypass_attrib = custom_page_drawer.newAttribute("Bypass setting to keep in screen", "1");
	if (drawer_directiontop_attrib.getData() == "1") drawer_directiontop_attrib.onDataChanged(); else drawer_directionbottom_attrib.onDataChanged();

	menubar_main_attrib = custom_page_menubars.newAttribute("Show Menus in Main Window", "1");
	menubar_pe_attrib = custom_page_menubars.newAttribute("Show Menus in Playlist Editor", "1");
	menubar_ml_attrib = custom_page_menubars.newAttribute("Show Menus in Media Library", "1");

	// create an attribute for each of our options, if the attribute already exists, it is returned
	vis_detach_attrib = custom_page.newAttribute("Detach Vis Window", "0");
	video_detach_attrib = custom_page.newAttribute("Detach Video Window", "0");
	eq_visible_attrib = custom_windows_page.newAttribute("Equalizer\tAlt+G", "0");

	windowshade_linkall_attrib = custom_page_windowshade.newAttribute("Link Position and Width", "1");
	windowshade_linkposition_attrib = custom_page_windowshade.newAttribute("Link Position, Unlink Width", "0");
	windowshade_linknone_attrib = custom_page_windowshade.newAttribute("Unlink Position and Width", "0");

}

// -----------------------------------------------------------------------------------------------------------------

#ifdef MAIN_ATTRIBS_MGR

Global Int attribs_mychange;

drawer_directiontop_attrib.onDataChanged() {
  if (attribs_mychange) return;
  attribs_mychange = 1;
  drawer_directionbottom_attrib.setData("0");
  drawer_directiontop_attrib.setData("1");
  attribs_mychange = 0;
}

drawer_directionbottom_attrib.onDataChanged() {
  if (attribs_mychange) return;
  attribs_mychange = 1;
  drawer_directiontop_attrib.setData("0");
  drawer_directionbottom_attrib.setData("1");
  attribs_mychange = 0;
}

windowshade_linkall_attrib.onDataChanged() {
  if (attribs_mychange) return;
  attribs_mychange = 1;
  windowshade_linkposition_attrib.setData("0");
  windowshade_linknone_attrib.setData("0");
  attribs_mychange = 0;
}

windowshade_linkposition_attrib.onDataChanged() {
  if (attribs_mychange) return;
  attribs_mychange = 1;
  windowshade_linkall_attrib.setData("0");
  windowshade_linknone_attrib.setData("0");
  attribs_mychange = 0;
}

windowshade_linknone_attrib.onDataChanged() {
  if (attribs_mychange) return;
  attribs_mychange = 1;
  windowshade_linkall_attrib.setData("0");
  windowshade_linkposition_attrib.setData("0");
  attribs_mychange = 0;
}

#endif

